<img src="https://raw.githubusercontent.com/LOAMRI/asltk/refs/heads/develop/docs/assets/asltk-logo.png" width=200>

[![Documentation Stable](https://readthedocs.org/projects/asltk/badge/?version=main)](https://asltk.readthedocs.io/en/main/?badge=main)
![Website](https://img.shields.io/website?url=https%3A%2F%2Fasltk.readthedocs.io%2Fen%2Fmain%2F&up_message=asltk%20documentation&link=https%3A%2F%2Fasltk.readthedocs.io%2Fen%2Fmain%2F)
[![codecov](https://codecov.io/gh/LOAMRI/asltk/graph/badge.svg?token=1W8GQ7SLU9)](https://codecov.io/gh/LOAMRI/asltk)
[![CI_main](https://github.com/LOAMRI/asltk/actions/workflows/ci_main.yaml/badge.svg)](https://github.com/LOAMRI/asltk/actions/workflows/ci_main.yaml)
[![CI_develop](https://github.com/LOAMRI/asltk/actions/workflows/ci_develop.yaml/badge.svg)](https://github.com/LOAMRI/asltk/actions/workflows/ci_develop.yaml)
![Python Versions](https://img.shields.io/badge/python-3.10%20|+-blue)
[![PyPI downloads](https://img.shields.io/pypi/dm/asltk?label=PyPI%20downloads)](https://pypi.org/project/asltk/)
![Contributors](https://img.shields.io/github/contributors/LOAMRI/asltk)
[![GitHub issues](https://img.shields.io/github/issues-raw/LOAMRI/asltk.svg?maxAge=2592000)]()
[![GitHub Sponsor](https://img.shields.io/badge/Sponsor-❤️%20acsenrafilho-orange?logo=github)](https://github.com/sponsors/acsenrafilho)

# Arterial Spin Labeling Toolkit (asltk)

Welcome to the ASL toolkit!

This library was designed to assist users in processing Arterial Spin Labeling (ASL) MRI images, from basic imaging protocols to the state-of-the-art models provided in the scientific literature.

The major objective of this project is to give an open-source alternative to researchers in the MRI field. A profound knowledge of computing and data modelling is not a prior demand. It is expected that a simple set of Python commands can be helpful in fast prototyping an ASL experiment or even collecting simple quantitative ASL-based information.

Please read the [full documentation](https://asltk.readthedocs.io/en/main/) to get more details about the usage, implementation and updates in the `asltk` library. 

Also, feel free to contribute directly to the project! Check it out the [issues](https://github.com/LOAMRI/asltk/issues) at the repository and get in touch to the developers of the project. 


## How to install

A quick to use install is via `pip`, as follows:

> [!NOTE]
> The installation requires Python 3.9 or higher

```bash
pip install asltk
```

## Special thanks for all the contributors

Thank you all the special people that invested their time and knowledge to improve this project. 👏

![Contributors](https://contrib.rocks/image?repo=LOAMRI/asltk)

## Citation

We appreciate if one or more of the following references can be added in your projects due to the usage of `asltk` outcomes.

* Senra Filho, A.C.; Paschoal, A. M. "Open-Source Multi-Echo (TE) MRI Tool for Arterial Spin Labelling Imaging Protocols". ISMRM Brazilian Chapter, 2025.
